Amazon, Macmillan make peace over book pricing | New York Post
Author: http://nypost.com/author/keith-j-kelly/
Description: Barely a shot was fired. Book publishing giant Macmillan announced a peaceful settlement with Amazon on Thursday on pricing for print and digital books ordered through the giant online retailer. Si...
Date: 2014-12-19T04:38:49+00:00

### Thanks for contacting us. We've received your submission.

Back to Reading

## Keith J. Kelly

Media

Media Ink

### Share this:

- Share

- Facebook
- Twitter
- Google
- WhatsApp
- Email

# Amazon, Macmillan make peace over book pricing

By Keith J. Kelly

- View author archive
- email the author
- follow on twitter
- Get author RSS feed

Name(required)
Email(required)
Comment(required)

December 18, 2014 | 11:38pm

Modal Trigger
Photo: Getty Images

### MORE FROM

###### Keith J. Kelly

##### A Time Inc. merger or purchase will not risk tax-free stock swap

##### Magazines boomed during 2014

##### Time Inc. cuts loose founding editor of People

##### Times set to drop popular advertising column

##### Condé Nast hosts scaled down year-end party at MoMA

Barely a shot was fired.

Book publishing giant Macmillan announced a peaceful settlement with Amazon on Thursday on pricing for print and digital books ordered through the giant online retailer.

Similar agreements were reached with Simon & Schuster in October and Hachette in November.

Hachette had waged a bruising six-month public battle with Amazon — claiming the e-tailer was acting as a bully by forcing book prices to unacceptably low levels that hurt publishers’ profits and authors’ commissions.

Amazon countered that it was trying to get the best deal for consumers — who would ultimately buy more books, which would ultimately generate more revenue for publishers.

While the battle was fierce between Hachette and Amazon, the Macmillan-Amazon dust-up was more civil — as were the settlement talks.

Macmillan, which owns Henry Holt, Picador and St. Martin’s, is part of the Germany-based von Holtzbrinck group.

After the settlement was reached, Macmillan CEO John Sargent said in a posting to authors, illustrators and agents that, while he is pleased with the deal, there are still some unsettling elements.

Amazon released a separate statement saying, “It allows us to grow our business together with Macmillan and their authors. Importantly, the agreement specifically creates a financial incentive for Macmillan to deliver lower prices for readers.”

But the days of super-discounting appear to be ending.

Amazon’s agreements with each of the three publishers embrace what has been called the “agency model” of book pricing — which allows each publisher to set the price that the books will be sold at.

Macmillan’s deal with Apple allows the Cupertino, Calif., company to be the only retailer allowed unlimited discounting, Sargent said in his post.

“Irony prospers in the digital age,” he added. The reference to “irony” refers to the long-running anti-trust case that the Department of Justice had leveled against five publishers and Apple, claiming that the publishers conspired to fix prices in a battle to gain leverage over Amazon.

Eventually, all five publishers reached out-of-court settlements. Apple fought on and is currently appealing a ruling that said it, too, had engaged in price-fixing with the publishers and must pay a hefty $450 million fine.

Sargent said a two-year consent agreement allowing Amazon to discount prices expired on Dec. 18.

Under a separate ruling in that case, Sargent said Apple can discount prices until Oct. 5, 2017. He complained that this wrinkle will “ensure a muddled and inefficient market.”

### Share this:

- Share

- Facebook
- Twitter
- Google
- WhatsApp
- Email

Filed under Amazon , e-books , Media Ink

### Share this:

- Share

- Facebook
- Twitter
- Google
- WhatsApp
- Email

Read Next:

Times set to… Times set to drop popular… Times set to drop popular advertising column

Recommended For You
Loading, please wait...
Most Popular This Week
1
Arrests plummet 66% with NYPD in virtual work stoppage
2
Three cheers for the NYPD
3
Cops turn backs on de Blasio at executed officer’s funeral
4
‘It was rough, man': Rex Ryan speaks to cap his whirlwind day
5
Astrophysicist angers Christians with Christmas tweet
6
Passenger tossed after flipping out over staff’s ‘Merry Christmas’

Share Selection

Facebook Twitter
Send to Email Address Your Name Your Email Address Cancel
Post was not sent - check your email addresses!
Email check failed, please try again
Sorry, your blog cannot share posts by email.

# Sign Up / Sign In Sign In // Sign Up

## With your existing account from...

{* loginWidget *}

## Use an account with your email address

{* #userInformationForm *} {* traditionalSignIn_emailAddress *} {* traditionalSignIn_password *}
{* traditionalSignIn_signInButton *}{* traditionalSignIn_createButton *}
{* /userInformationForm *}

# Sign Up / Sign In Sign In // Sign Up

## Welcome Back, {* welcomeName *}

{* loginWidget *}
Use an account with your email address

# Sign Up / Sign In Sign In // Sign Up

## Welcome back!

{* welcomeName *}
{* #userInformationForm *} {* traditionalSignIn_emailAddress *} {* traditionalSignIn_password *}
{* traditionalSignIn_signInButton *}
{* /userInformationForm *}
Use an account with your email address

# Almost Done!

{* #registrationForm *} {* traditionalRegistration_emailAddress *} {* traditionalRegistration_password *} {* traditionalRegistration_passwordConfirm *} {* traditionalRegistration_displayName *} {* traditionalRegistration_captcha *} {* traditionalRegistration_ageVerification *} By clicking "Create Account", you confirm that you accept our terms of service and have read and understand privacy policy.
{* /registrationForm *}

# Create a new password Forgot
Password?

## Don't worry, it happens. We'll send you a link to create a new password.

{* #forgotPasswordForm *} {* traditionalSignIn_emailAddress *}
{* /forgotPasswordForm *}

# Create a new password Sent!

We've sent an email with instructions to create a new password. Your existing password has not been changed.

# Account Already Exists

{* mergeAccounts *}
{* backButton *}

# Sign in to complete account merge

{* #tradAuthenticateMergeForm *} {* traditionalSignIn_emailAddress *} {* mergePassword *}
{* /tradAuthenticateMergeForm *}